@@ -8,12 +8,12 @@
 * Chip type           : AT90S4433
 * Clock frequency     : 4,19 MHz
 *********************************************/
-#include <io.h>
-#include <progmem.h>
-#include <interrupt.h>
-#include <string-avr.h>
+#include <avr/io.h>
+#include <avr/pgmspace.h>
+#include <avr/interrupt.h>
+#include <string.h>
 #include <stdlib.h>
-#include <sig-avr.h>
+#include <avr/signal.h>
 #include "lcd.h" 
 #include "avr-util.h" 
 #include "uart.h"
