@@ -6,7 +6,7 @@
 ***************************************************************************/
 #ifndef UART_H
 #define UART_H
-#include <pgmspace.h>
+#include <avr/pgmspace.h>
 
 /* public result buffer len for uart_outbuf */ 
 #define UART_RX_BUFFER_SIZE 8
